==> freerdp-2.6.0-x86_64-1.txz: usr/lib64/cmake/FreeRDP-Shadow2/FreeRDP-ShadowTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "freerdp-shadow" for configuration "Release"
set_property(TARGET freerdp-shadow APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(freerdp-shadow PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "freerdp;freerdp-server;winpr;winpr-tools"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libfreerdp-shadow2.so.2.6.0"
  IMPORTED_SONAME_RELEASE "libfreerdp-shadow2.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS freerdp-shadow )
list(APPEND _IMPORT_CHECK_FILES_FOR_freerdp-shadow "${_IMPORT_PREFIX}/lib64/libfreerdp-shadow2.so.2.6.0" )

# Import target "freerdp-shadow-subsystem" for configuration "Release"
set_property(TARGET freerdp-shadow-subsystem APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(freerdp-shadow-subsystem PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "freerdp-shadow;freerdp;winpr"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libfreerdp-shadow-subsystem2.so.2.6.0"
  IMPORTED_SONAME_RELEASE "libfreerdp-shadow-subsystem2.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS freerdp-shadow-subsystem )
list(APPEND _IMPORT_CHECK_FILES_FOR_freerdp-shadow-subsystem "${_IMPORT_PREFIX}/lib64/libfreerdp-shadow-subsystem2.so.2.6.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> freerdp-2.10.0-x86_64-1.txz: usr/lib64/cmake/FreeRDP-Shadow2/FreeRDP-ShadowTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "freerdp-shadow" for configuration "Release"
set_property(TARGET freerdp-shadow APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(freerdp-shadow PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "freerdp;freerdp-server;winpr;winpr-tools"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libfreerdp-shadow2.so.2.10.0"
  IMPORTED_SONAME_RELEASE "libfreerdp-shadow2.so.2"
  )

list(APPEND _cmake_import_check_targets freerdp-shadow )
list(APPEND _cmake_import_check_files_for_freerdp-shadow "${_IMPORT_PREFIX}/lib64/libfreerdp-shadow2.so.2.10.0" )

# Import target "freerdp-shadow-subsystem" for configuration "Release"
set_property(TARGET freerdp-shadow-subsystem APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(freerdp-shadow-subsystem PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "freerdp-shadow;freerdp;winpr"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libfreerdp-shadow-subsystem2.so.2.10.0"
  IMPORTED_SONAME_RELEASE "libfreerdp-shadow-subsystem2.so.2"
  )

list(APPEND _cmake_import_check_targets freerdp-shadow-subsystem )
list(APPEND _cmake_import_check_files_for_freerdp-shadow-subsystem "${_IMPORT_PREFIX}/lib64/libfreerdp-shadow-subsystem2.so.2.10.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
